rm(list=ls())# wipes slate clean
library(dplyr)
library(ggplot2)
library(coin)
library(MASS)
library(foreign)
library(Hmisc)
library(reshape2)
library(mgcv)
library(lme4)
library(lmerTest)
library(gridExtra)

setwd("C:/Users/Ragenaky/Desktop/Striga Madagascar 2020/Completed Sheets/Ecology Data Updated")


# Useful functions later on....

#Calculate a standard error
stderr <- function(x) sd(x) / sqrt(length(x))

# Multiple plot function

### Install this When you start for Multiplots!!!#####
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}




# Read in the data
LC_1<-read.csv("LEGUME_CROP_2019_2020_SINGLE_RECS_REMOVED.CSV")

# (2) Look at effects of different legume crops 

# Set contrasts so that we can test against the grand mean.
options(contrasts = c("contr.sum","contr.poly")) 
lm1 <- lm( log( AvDen + 1 )  ~    YR * LC, data = LC_1) 
anova(lm1)
summary(lm1)

model1 <- lm(log( AvDen + 1) ~ LC - 1, data = LC_1)
coeffs <- data.frame( summary(model1)$coefficients )
ix <- sort(coeffs$Estimate, index.return = TRUE)$ix
coeffs <- coeffs[ix,]
coeffs$names <- str_remove( rownames(coeffs), "LC" )
coeffs <- coeffs[-idx,]

summaryLC <- LC_1 %>% group_by(LC) %>% 
  summarise( meanAvDen = mean(AvDen), se = stderr(AvDen))

fig5 <- ggplot(coeffs, aes(x = reorder( names, Estimate), y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 12), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 12),
         legend.position="none",
         axis.title.x=element_text( size = 14 ),
         axis.title.y=element_text( size = 14 ) ) +
  geom_hline(yintercept = mean(summaryLC$meanAvDen), linetype  = "dashed") +
  labs( x = "Legume Crop", y = "Log Striga density") + 
  theme(axis.text.x = element_text(angle = 50, hjust=.91)) 

fig5

## Old code below
#Makes the mean line
summaryLC <- LC_1 %>% group_by(LC) %>% 
  summarise( meanAvDen = mean(AvDen), se = stderr(AvDen))



Figure1 <- ggplot( summaryLC, aes(x = LC, y = meanAvDen) ) +	
  geom_point( size = 1) +
  geom_errorbar( aes(ymin = meanAvDen - se, ymax = meanAvDen + se), width = 0.1, position = position_dodge(width = 0.25) )  +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         legend.position="none",
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.text.x = element_text(size = 10),
         axis.text.y = element_text(size = 8),
         axis.title.x=element_text(size = 14),
         axis.title.y=element_text(size = 14) ) +
         geom_hline(yintercept = mean(summaryLC$meanAvDen), linetype  = "dashed") +
  labs(x = "Legume Crop") + labs( y = "Log Striga density", las=2)

Figure1



