rm(list=ls())# wipes slate clean
library(mgcv)
library(lme4)
library(lmerTest)
library(ggplot2)
library(dplyr)
library( geosphere )
library( stringr)

#Calculate a standard error
stderr <- function(x, ...) sd(x, na.rm = TRUE) / sqrt(length(is.na(x == FALSE)) )


### Install this When you start for Multiplots!!!#####
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}



# Have cleaned the cultivar variable
fulldata <- read.csv("/Users/Ragenaky/Desktop/Striga Madagascar 2020/Completed Sheets/Ecology Data Updated/MASTER_2019_2020_NANC.csv", h = T)

fulldata$YR <- as.factor(fulldata$YR)
fulldata$FN <- as.factor(fulldata$FN)




# Load NO3 data

NO3 <- read.csv("/Users/Ragenaky/Desktop/Striga Madagascar 2020/Completed Sheets/Ecology Data Updated/NO3_2019_2020.csv", h = T)
colnames(NO3)[1] <- "YR"
NO3Summary <- NO3 %>% 
  group_by(YR, Field) %>% 
  summarise( NO3 = mean(NO3_ppm), avdenCHECK = mean(AvDen) )
NO3Summary <- data.frame(NO3Summary)


NO3idx <- apply(fulldata, 1, function(x) { idx  <- which( NO3Summary$YR == x[1] & NO3Summary$Field == x[2]) 
                                ret <- NA
                                if(length(idx) >0 ) ret <- NO3Summary[idx,3]
                                ret} )
fulldata$NO3 <- NO3idx

# Load neighbour data
  

# Functions to find neighbour densities

findNN <- function( p, pts) {
  dists <- distm(p, pts, fun = distHaversine )
  idxN1 <- which( dists == min( dists ) )
  idxN2 <- which( dists == min( dists[-idxN1] ) )
  idxN3 <- which( dists == min( dists[-c(idxN1, idxN2) ] ) )
  return( c(idxN2, idxN3) )
}

NNdens <- function(pts, dens) {
  idxs <- t( apply( pts, 1, function(x) findNN(x, pts)) )
  Ns <- apply(idxs,1, function(idx) mean(dens[idx]) )
  return(Ns)
}

# Run
data2019 <- fulldata[ which(fulldata$YR == 2019), ]
data2020 <- fulldata[ which(fulldata$YR == 2020), ]

ptest <- c( data2019$Lon[1], data2019$Lat[1] )
ptstest <- cbind(data2019$Lon , data2019$Lat  )
Neigh2019 <- unlist( NNdens( ptstest, data2019$AvDen ) )

ptest <- c( data2020$Lon[1], data2020$Lat[1] )
ptstest <- cbind(data2020$Lon , data2020$Lat  )
Neigh2020 <- unlist( NNdens( ptstest, data2020$AvDen ) )

fulldata$Neigh <- c( Neigh2019, Neigh2020 )



#Table 3a

# Rice Variety
riceData <- fulldata[which(fulldata$R_M_O == "Rice"),]
model1 <- lm( log( AvDen + 1) ~  YR * CVclean  , data = riceData )
anova(model1)



# Here is a way to display the results:
model1 <- lm( log( AvDen + 1) ~   CVclean -1 , data = riceData )
coeffs <- data.frame( summary(model1)$coefficients )
ix <- sort(coeffs$Estimate, index.return = TRUE)$ix
coeffs <- coeffs[ix,]
coeffs$names <- str_remove( rownames(coeffs), "CVclean" )
idx <- which(coeffs$Estimate == 0)
coeffs <- coeffs[-idx,]


fig2a <- ggplot(coeffs, aes(x = reorder( names, Estimate), y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Rice Variety", y = "Log Striga density") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65))


#Previous crop

model2 <- lm(log( AvDen + 1) ~  YR * PC, data = fulldata)
anova(model2)


# Here is a way to display the results:
model2 <- lm(log( AvDen + 1) ~ PC - 1, data = fulldata)
coeffs <- data.frame( summary(model2)$coefficients )
ix <- sort(coeffs$Estimate, index.return = TRUE)$ix
coeffs <- coeffs[ix,]
coeffs$names <- str_remove( rownames(coeffs), "PC" )
idx <- which(coeffs$Estimate == 0)
coeffs <- coeffs[-idx,]

fig2b <- ggplot(coeffs, aes(x = reorder( names, Estimate), y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Previous crop", y = "Log Striga density") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.85))




# Previous crop legume
model3 <- lm(log( AvDen + 1) ~ YR * PCL , data = fulldata)
anova(model3)


# Here is a way to display the results:
model3 <- lm(log( AvDen + 1) ~PCL - 1, data = fulldata)
coeffs <- data.frame( summary(model3)$coefficients )
ix <- sort(coeffs$Estimate, index.return = TRUE)$ix
coeffs <- coeffs[ix,]
coeffs$names <- c("Legume present", "No legume")



fig2c <- ggplot(coeffs, aes(x = reorder( names, Estimate), y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.15, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Previous crop legume", y = "Log Striga density") + 
  theme(axis.text.x = element_text(angle = 0, vjust = .6)) 


#Companion Crop
model4 <- lm(log( AvDen + 1) ~  YR * CC, data = fulldata)
anova(model4)


# Here is a way to display the results:
model4 <- lm(log( AvDen + 1) ~  CC - 1 , data = fulldata)
coeffs <- data.frame( summary(model4)$coefficients )
ix <- sort(coeffs$Estimate, index.return = TRUE)$ix
coeffs <- coeffs[ix,]
coeffs$names <- str_remove( rownames(coeffs), "CC" )
idx <- which(coeffs$Estimate == 0)
coeffs <- coeffs[-idx,]



fig2d <- ggplot(coeffs, aes(x = reorder( names, Estimate), y = Estimate) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = Estimate - Std..Error, ymax =Estimate + Std..Error ), width = 0.5, size = 0.25 ) +
  theme_bw() + theme(axis.text.x = element_text(angle = 45))+
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 8), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  
  labs( x = "Intercrop", y = "Log Striga density") + 
  theme(axis.text.x = element_text(angle = 50, vjust = .7, hjust=.65)) 


# Suggestion for Figure 2:

multiplot(fig2a + labs( tag = "A"), fig2b + labs( tag = "B"), fig2c + labs( tag = "C"), fig2d + labs( tag = "D"), cols = 2)



# Table 3b

# Neighbouring density

model5 <- lm( log( AvDen + 1) ~   YR * Neigh , data = fulldata)
anova(model5)

summaryN <- fulldata %>% 
  group_by( round(AvDen) ) %>% 
  summarise( meanN = mean(AvDen), SE = stderr(AvDen) )

fig3a <- ggplot(summaryN, aes(x = `round(AvDen)`, y = meanN) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = meanN - SE, ymax = meanN + SE), width = 0.5, size = 0.25 ) +
  theme_bw() +
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mean field density", y = "Density of closest neighbours") + 
  theme(axis.text.x = element_text(angle = 90)) 


# Mean rainfall
model6 <- lm( log(AvDen + 1) ~ YR * MeanRF, data = fulldata )
anova(model6)

fulldataA <- fulldata
fulldataA$rainCat <- round(fulldataA$ MeanRF / 3.5) * 3.5
summaryRain <- fulldataA %>% 
  group_by( rainCat ) %>%
  summarise( meanN = mean(AvDen, na.rm = TRUE), SE = stderr(AvDen, na.rm = TRUE)  )

fig3b <- ggplot(summaryRain, aes(x = rainCat, y = meanN) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = meanN - SE, ymax = meanN + SE), width = 0.5, size = 0.25 ) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mean rainfall (mm)", y = "Mean Striga density") + 
  theme(axis.text.x = element_text(angle = 90)) 




# Precipitation seasonality
model7 <- lm( log(AvDen + 1) ~ YR * RFCV_MAN, data = fulldata )
anova(model7)

fulldataA <- fulldata
fulldataA$RFCVCat <- round(fulldataA$ RFCV_MAN / 1.25) * 1.25
summaryRFCV <- fulldataA %>% 
  group_by( RFCVCat ) %>%
  summarise( meanN = mean(AvDen, na.rm = TRUE), SE = stderr(AvDen, na.rm = TRUE)  )

fig3c <- ggplot(summaryRFCV, aes(x = RFCVCat, y = meanN) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = meanN - SE, ymax = meanN + SE), width = 0.5, size = 0.25 ) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Precipitation seasonality (CV)", y = "Mean Striga density") + 
  theme(axis.text.x = element_text(angle = 90))


# ------------------------------

# altitude
model8 <- lm( log( AvDen + 1 ) ~ YR * Alt, data = fulldata)
anova(model8)

fulldataA <- fulldata
fulldataA$altCat <- round(fulldataA$Alt / 100) * 100
summaryAlt <- fulldataA %>% 
  group_by( altCat ) %>%
  summarise( meanN = mean(AvDen, na.rm = TRUE), SE = stderr(AvDen, na.rm = TRUE)  )


fig3d <- ggplot(summaryAlt, aes(x = altCat, y = meanN) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = meanN - SE, ymax = meanN + SE), width = 0.5, size = 0.25 ) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Altitude (m)", y = "Mean Striga density") + 
  theme(axis.text.x = element_text(angle = 90)) 


# Mean temperature

model9 <- lm( log(AvDen + 1) ~ YR * MeanTA, data = fulldata  )
anova(model9)

fulldataA <- fulldata
fulldataA$tempCat <- round(fulldataA$MeanTA / 1) * 1
summaryTemp <- fulldataA %>% 
  group_by( tempCat ) %>%
  summarise( meanN = mean(AvDen, na.rm = TRUE), SE = stderr(AvDen, na.rm = TRUE)  )


fig3e <- ggplot(summaryTemp, aes(x = tempCat, y = meanN) ) +
  geom_point(size = 1) + 
  geom_errorbar(aes( ymin = meanN - SE, ymax = meanN + SE), width = 0.5, size = 0.25 ) +
  theme_bw() + 
  theme( panel.border = element_blank(), 
         panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), 
         axis.line = element_line(colour = 'black', size = 0.25),
         axis.ticks = element_line(colour = "black", size = 0.25),
         axis.ticks.length=unit(-0.25, "cm"), 
         axis.text.x = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10), 
         axis.text.y = element_text(margin=unit(c(0.5,0.5,0.5,0.5), "cm"), size = 10),
         legend.position="none",
         axis.title.x=element_text( size = 12 ),
         axis.title.y=element_text( size = 12 ) ) +
  labs( x = "Mean Temperature (\u00B0C)", y = "Mean Striga Density") + 
  theme(axis.text.x = element_text(angle = 90)) 

multiplot(fig3a + labs( tag = "A"), fig3b+ labs( tag = "B"), fig3c+ labs( tag = "C"), fig3d+ labs( tag = "D"),fig3e+ labs( tag = "E"), cols = 2)

# NO3
model10 <- lm( log(AvDen + 1 ) ~ YR * NO3, data = fulldata )
anova(model10)

attach(fulldata)

plot(NO3, AvDen , main="Mean Striga Density and Mean NO3",
     xlab="Mean NO3 ", ylab="Mean Striga Density ", pch=19)









